==> get_cell-0.0.2.tar.gz: get_cell-0.0.2/src/cell_content/getcellcontent.py <==
import IPython
import re
def find_cell_text(expected_id):
    """
    Tìm kiếm và trả về chỉ mục của ô có ID mong đợi.

    Args:
        expected_id (str): ID của ô cần tìm.

    Returns:
        int: Chỉ mục của ô có ID mong đợi.
    """
    indexs = []
    # Get a reference to the current InteractiveShell object
    shell = IPython.get_ipython()

    # Get the input history
    input_history = shell.history_manager.get_range()
    # Print the input history
    for i, (session, line_num, input_text) in enumerate(input_history):
        for line in input_text.split('\n'):
            if line.startswith('#__cell_id__: '):
                cell_id = line.strip()[11:]
                if cell_id == expected_id:
                    return input_text
    return -1


def cell_content(expected_id):
    """
    Trả về nội dung của ô có ID mong đợi mà không có những comment.

    Args:
        expected_id (str): ID của ô cần tìm.

    Returns:
        str: Nội dung của ô được xử lý (loại bỏ comment và dòng trống).
    """
    text = find_cell_text(expected_id)
    # Remove single-line comments
    pattern = re.compile(r'(?m)^\s*#.*\n')
    text = re.sub(pattern, '', text)

    # Remove multi-line comments and triple-quoted strings
    pattern = re.compile(r'(?s)(\'\'\'|""").*?\1|/\*.*?\*/')
    text = re.sub(pattern, '', text)

    # Remove blank lines
    pattern = re.compile(r'(?m)^\s*\n')
    text = re.sub(pattern, '', text)
    # Print the code without comments
    # Remove whitespace in each line
    python_code = re.sub(r'\s+', lambda m: '\n' if '\n' in m.group(0) else '', text)

    # Print the modified code
    return python_code

==> get_cell-0.0.3.tar.gz: get_cell-0.0.3/src/cell_content/getcellcontent.py <==
import IPython
import re
def find_cell_text(expected_id):
    """
    Tìm kiếm và trả về chỉ mục của ô có ID mong đợi.

    Args:
        expected_id (str): ID của ô cần tìm.

    Returns:
        int: Chỉ mục của ô có ID mong đợi.
    """
    indexs = []
    # Get a reference to the current InteractiveShell object
    shell = IPython.get_ipython()

    # Get the input history
    input_history = shell.history_manager.get_range()
    # Print the input history
    for i, (session, line_num, input_text) in enumerate(input_history):
        for line in input_text.split('\n'):
            if line.startswith('#__cell_id__: '):
                cell_id = line.strip()[len('#__cell_id__: '):]
                if cell_id == expected_id:
                    return input_text
    return -1


def cell_content(expected_id):
    """
    Trả về nội dung của ô có ID mong đợi mà không có những comment.

    Args:
        expected_id (str): ID của ô cần tìm.

    Returns:
        str: Nội dung của ô được xử lý (loại bỏ comment và dòng trống).
    """
    text = find_cell_text(expected_id)
    # Remove single-line comments
    pattern = re.compile(r'(?m)^\s*#.*\n')
    text = re.sub(pattern, '', text)

    # Remove multi-line comments and triple-quoted strings
    pattern = re.compile(r'(?s)(\'\'\'|""").*?\1|/\*.*?\*/')
    text = re.sub(pattern, '', text)

    # Remove blank lines
    pattern = re.compile(r'(?m)^\s*\n')
    text = re.sub(pattern, '', text)
    # Print the code without comments
    # Remove whitespace in each line
    python_code = re.sub(r'\s+', lambda m: '\n' if '\n' in m.group(0) else '', text)

    # Print the modified code
    return python_code
